import time
import json
from amari_test_common import WebsocketTestBase

class ORSTest(WebsocketTestBase):
    @classmethod
    def setTestParameters(cls):
        cls.enb_instance_name = time.strftime('e2e-ors84-enb-%Y-%B-%d-%H:%M:%S')
        cls.cn_instance_name = time.strftime('e2e-ors84-core-network-%Y-%B-%d-%H:%M:%S')
        cls.sim_instance_name = time.strftime('e2e-ors84-sim-%Y-%B-%d-%H:%M:%S')
        cls.ue_instance_name = time.strftime('e2e-sb005-ue-%Y-%B-%d-%H:%M:%S')

        cls.product = cls.product.get('ors-tdd')
        cls.ue_product = "/opt/e2e/slapos/software/ors-amarisoft/software-fdd-lopcomm.cfg"

        cls.comp_enb = "COMP-4057"
        cls.comp_cn = "COMP-4057"
        cls.comp_ue = "COMP-3756"

        cls.dl_earfcn = 38550

    def test_ue_has_ip(self):
        result = self.recv()
        result = self.ue_get()
        ue_id = result['ue_id']

        try:
            self.power_on(ue_id)
            time.sleep(5)
            result = self.ue_get()
            self.assertIn('pdn_list', result, "UE didn't connect")
            self.assertIn('ipv4', result['pdn_list'][0], "UE didn't get IPv4")
            self.logger.info("UE connected with ip: " + result['pdn_list'][0]['ipv4'])
        finally:
            self.power_off(ue_id)


    def test_max_rx_sample_db(self):
        custom_params = {"max_rx_sample_db": -99}
        self.request_enb(custom_params)
        self.waitUntilPromises(self.enb_instance_name, promise_name="check-rx-saturated", expected=False)

    def test_min_rxtx_delay(self):
        # Fixed by 9798ef1e, change `expected` to False when released
        custom_params = {"min_rxtx_delay": 99}
        self.request_enb(custom_params)
        self.waitUntilPromises(self.enb_instance_name, promise_name="check-baseband-latency", expected=True)
